---
title: Getting Started
nav_order: 3
---

<p align="center">
  <img src="{{site.baseurl}}/images/treadi_logo.svg" alt="logo life ring resembling github issue icon" width="256"/>
</p>

Well, this is awkward!
This guide hasn't been written yet.
Check out the reference pages on the left for now.